imputationMean: Imputation with Variable Mean

View source: R/imputationMean.R

imputationMeanR Documentation

Imputation with Variable Mean

Description

Replace missing values in data with the mean of that element's column or row.

Usage

imputationMean(x, by.row = FALSE, row.range = 1:nrow(x), col.range = 1:ncol(x))

Arguments

x

A matrix-like R object with two dimensions to perform imputation on.

by.row

A logical value indicating whether to calculate the mean by the values within an element's row or not. Default = TRUE

row.range

A numeric vector containing the row numbers to be included in the mean calculation and imputation.

col.range

A numeric vector containing the column numbers to be included in the mean calculation and imputation.

Value

Returns the passed data with missing values imputed with the mean of each element's respective row or column.

Examples

# Default by column
imputed_mean <- imputationMean(data)

# By row, excluding the first column.
imputed_mean_byrow <- imputationMean(data_byrow,
col.range = 2:ncol(data_byrow))

Echinoidea/hooks-imputation documentation built on May 8, 2022, 4:39 p.m.