View source: R/imputationMean.R
| imputationMean | R Documentation |
Replace missing values in data with the mean of that element's column or row.
imputationMean(x, by.row = FALSE, row.range = 1:nrow(x), col.range = 1:ncol(x))
x |
A matrix-like R object with two dimensions to perform imputation on. |
by.row |
A logical value indicating whether to calculate the mean by the
values within an element's row or not. Default = |
row.range |
A numeric vector containing the row numbers to be included in the mean calculation and imputation. |
col.range |
A numeric vector containing the column numbers to be included in the mean calculation and imputation. |
Returns the passed data with missing values imputed with the mean of each element's respective row or column.
# Default by column imputed_mean <- imputationMean(data) # By row, excluding the first column. imputed_mean_byrow <- imputationMean(data_byrow, col.range = 2:ncol(data_byrow))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.